@@ -6,7 +6,7 @@ fn main() {
     let mut win = window::Window::default().with_size(400, 300);
     let mut flex = Flex::new(0, 0, 400, 300, None);
     flex.set_type(FlexType::Column);
-    let expanding = button::Button::default().with_label("Expanding");
+    let _expanding = button::Button::default().with_label("Expanding");
     let mut normal = button::Button::default().with_label("Normal");
     flex.set_size(&mut normal, 30);
     flex.end();
